@@ -1,4 +1,5 @@
 # pylint: disable=import-error
+import json
 import backoff
 import requests
 from requests.adapters import HTTPAdapter
@@ -79,13 +80,16 @@ class SyncariRestClient:
             req = requests.Request(method, url, **kwargs).prepare()
             resp = self._session.send(req, stream=stream)
         except Exception as e:
-            raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=str(resp), status_code=400))
+            raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=str(e), status_code=400))
 
         if resp.status_code == 500:
+            logger.error(resp)
             raise RetryableException(resp)
 
         if resp.status_code not in self.success_responses:
-            raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=str(resp), status_code=resp.status_code))
+            error_resp = ErrorResponse(message=err_msg, detail=self.__get_error_response_details(resp), status_code=resp.status_code)
+            logger.error(error_resp)
+            raise SyncariException(error_response=error_resp)
 
         return resp
 
@@ -96,3 +100,14 @@ class SyncariRestClient:
         url = self.rest_url+path
         logger.info("%s: %s", method, url)
         return self._retryable_request(method, url, **kwargs)
+
+    def __get_error_response_details(self, error):
+        """
+            A simple wrapper to get error response in a readable format
+        """
+        error_resp_json = {
+            'reason': error.reason,
+            'status_code': error.status_code,
+            'content': error.text
+        }
+        return json.dumps(error_resp_json)
